
Example of 'viewcode' usage
===========================

see `viewcode extension page`_ for more documentation.

Include link to source code on the side of class or function description.

.. autoclass:: {{base.pkg_full_name, }}.example_doc.MyObj

.. _`viewcode extension page`: http://www.sphinx-doc.org/en/stable/ext/viewcode.html
